package org.apache.bcel.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import org.apache.bcel.classfile.ClassParser;
import org.apache.bcel.classfile.JavaClass;

public class ClassLoaderRepository implements Repository {
   private final java.lang.ClassLoader loader;
   private final Map<String, JavaClass> loadedClasses = new HashMap();

   public ClassLoaderRepository(java.lang.ClassLoader loader) {
      this.loader = loader;
   }

   public void clear() {
      this.loadedClasses.clear();
   }

   public JavaClass findClass(String className) {
      return (JavaClass)this.loadedClasses.get(className);
   }

   public ClassPath getClassPath() {
      return null;
   }

   public JavaClass loadClass(Class<?> clazz) throws ClassNotFoundException {
      return this.loadClass(clazz.getName());
   }

   public JavaClass loadClass(String className) throws ClassNotFoundException {
      String classFile = className.replace('.', '/');
      JavaClass RC = this.findClass(className);
      if (RC != null) {
         return RC;
      } else {
         try {
            InputStream is = this.loader.getResourceAsStream(classFile + ".class");
            Throwable var5 = null;

            JavaClass var7;
            try {
               if (is == null) {
                  throw new ClassNotFoundException(className + " not found.");
               }

               ClassParser parser = new ClassParser(is, className);
               RC = parser.parse();
               this.storeClass(RC);
               var7 = RC;
            } catch (Throwable var17) {
               var5 = var17;
               throw var17;
            } finally {
               if (is != null) {
                  if (var5 != null) {
                     try {
                        is.close();
                     } catch (Throwable var16) {
                        var5.addSuppressed(var16);
                     }
                  } else {
                     is.close();
                  }
               }

            }

            return var7;
         } catch (IOException var19) {
            IOException e = var19;
            throw new ClassNotFoundException(className + " not found: " + e, e);
         }
      }
   }

   public void removeClass(JavaClass clazz) {
      this.loadedClasses.remove(clazz.getClassName());
   }

   public void storeClass(JavaClass clazz) {
      this.loadedClasses.put(clazz.getClassName(), clazz);
      clazz.setRepository(this);
   }
}
